@@ -41,6 +41,7 @@ $ldap_server_no = 0;
  * If check user method is "mailbox", then supply here credentials which have
  * cyrusadmin rights, so that the existence of some other user's mailbox can be
  * checked. This method is not recommended.
+ * TODO - Not implemented yet.
  */
 $useracl_root_username = 'cyrusadmin';
 $useracl_root_password = 'secret';
@@ -51,5 +52,26 @@ $useracl_root_password = 'secret';
  */
 $show_ldap_cn = false;
 
-?>
+/**
+ * Enable option for notifying user?
+ * @var boolean
+ */
+$useracl_enable_notify = true;
 
+
+/**
+ * Show iconic image submit buttons?
+ * @var boolean
+ */
+$useracl_show_images = true;
+
+/**
+ * Insert here a URL that describes the shared folders functionality. Leave
+ * this empty ('') to disable.
+ * @var string
+ */
+
+$useracl_notify_url = '';
+//$useracl_notify_url = "http://mail.example.org/help/mail_folders_help.html";
+
+?>
